﻿if (QV === undefined) {
    var QV = {};
}
QV.util = {
    extend: function (o1, o2) {
        var k;
        for (k in o2) {
            if (o2.hasOwnProperty(k)) {
                o1[k] = o2[k];
            }
        }
        return o1;
    }
};

var offLineMessage = 'Connection Lost',
    dataOS = [
        {
            string: navigator.platform,
            subString: "Win",
            identity: "Windows"
        },
        {
            string: navigator.platform,
            subString: "Mac",
            identity: "Mac"
        },
        {
            string: navigator.userAgent,
            subString: "iPad",
            identity: "iPad",
            versStr: /OS (\d)/
        },
        {
            string: navigator.userAgent,
            subString: "iPhone",
            identity: "iPhone",
            versStr: /OS (\d)/
        },
        {
            string: navigator.platform,
            subString: "Linux",
            identity: "Linux"
        }
    ];

/* Using localStorage if available to store previously used application_url 
    If not available then simulate with cookie

    ISSUE: localStorage and Cookie not working with current player. test on newer player
*/
localStorageStub = {
    getItem: function (c_name) {
        var i, x, y, ARRcookies = document.cookie.split(";");
        for (i = 0; i < ARRcookies.length; i++) {
            x = ARRcookies[i].substr(0, ARRcookies[i].indexOf("="));
            y = ARRcookies[i].substr(ARRcookies[i].indexOf("=") + 1);
            x = x.replace(/^\s+|\s+$/g, "");
            if (x == c_name) {
                return unescape(y);
            }
        }
    },
    setItem: function (c_name, c_value) {
        var exdate = new Date(),
            exdays = 365;
        exdate.setDate(exdate.getDate() + exdays);
        var c_value = escape(c_value) + ((exdays == null) ? "" : "; expires=" + exdate.toUTCString());
        document.cookie = c_name + "=" + c_value;
    }
},

QV.env = {
    offLineMask: null,
    pingTimer: null,
    pingFile: 'apps/Signon/StatusCheck.js?callback=?',
    mainFile: 'nmp.html',
    clientId: '',
    clientVers: '',

    storage: window.localStorage || localStorageStub,

    init: function () {
        //$('#booting-mask h3').html(this.fetchOffLineMessage());
        QV.env.storage.setItem('application_url', QV.env.APPLICATION_URL);
        this.determineClient();
        this.appOffline();
        QV.env.ping();
        
    },



    fetchOffLineMessage: function () {
        var retString = "";
        switch (navigator.language.toLowerCase()) {
            case "de-de":
                retString = "Verbindung wurde unterbrochen";
                break;
            case "es-es":
                retString = "Sin conexi&oacute;n";
                break;
            case "pt-br":
                retString = "Sem conexão";
                break;
            case "ru-ru":
                retString = "Нет соединения";
                break;
            case "zh-cn":
                retString = "无连接";
                break;
            case "zh-tw":
                retString = "無連接";
                break;
            default:
                retString = "Connection Lost";
                break;
        }

        return retString;
    },
    ping: function () {
        QV.env.pingTimer = setTimeout(function () {
            //$('#booting-mask h3').addClass('show');
        }, 3000); // we can’t call error() with jsonp files…

        $.ajax(QV.env.APPLICATION_URL + QV.env.pingFile, {
            data: { alt: 'json-in-script' },
            dataType: 'jsonp',
            jsonp: false,
            success: function (oRes, sSt) {
                QV.env.appOnline();
            }
        });
    },
    appOnline: function () {
        //$('#booting-mask').removeClass('show');
        $("#page-splash").hide();
        sessionStorage.portno = window.location.port;
        sessionStorage.OS = this.clientId;
        window.location = QV.env.APPLICATION_URL + QV.env.mainFile;
    },
    appOffline: function () {
        //$('#booting-mask').addClass('show');
        $("#page-splash").show();
    },
    determineClient: function () {
        var aMat, i = 0;

        // check for client ID passed in via querystring
        if ((aMat = window.location.search.match(/OS=([a-z0-9]+)/i)) !== null) {
            this.setClientId(aMat[1], null);
            return true;
        }

        // otherwise, determine from the UA
        for (; i < dataOS.length; i++) {
            if (dataOS[i].string.indexOf(dataOS[i].subString) !== -1) {
                this.setClientId(dataOS[i].identity, dataOS[i]);
                return true;
            }
        }
        return false;
    },
    setClientId: function (sClientId, oClientDef) {
        this.clientId = sClientId;
        $('body').addClass(this.clientId.toLowerCase());

        // if we can’t detect the version
        if ((oClientDef === null) || (oClientDef.versStr === undefined)) {
            return;
        }

        // otherwise...
        if ((aMat = navigator.appVersion.match(oClientDef.versStr)) !== false) {
            this.clientVers = parseInt(aMat[1]);
            $('body').addClass(this.clientId.toLowerCase() + this.clientVers);
        }
    },
    showUrlOverride: function () {
        var $urlInput = $('#url-override');

        var application_url = QV.env.storage.getItem('application_url') || QV.env.APPLICATION_URL;

        $urlInput.attr('placeholder', application_url);

        $('#url-override-container').removeClass('hide')
            .bind('submit', function (ev) {
                QV.env.APPLICATION_URL = $urlInput.val() || $urlInput.attr('placeholder');

                QV.env.storage.setItem('application_url', QV.env.APPLICATION_URL);

                //QV.env.ping();
                QV.env.appOnline();
                return false;
            }
        );

        //QV.env.APPLICATION_URL = "http://labvodclientservices.dof6.com/YomviAndroidDes/";
        //QV.env.storage.setItem('application_url', QV.env.APPLICATION_URL);
        //QV.env.appOnline();
    }

};


(function ($) {

    $(function () {
        QV.env.init();
    });


})(jQuery);



